@@ -213,7 +213,7 @@ class Application(object):
 		"""Start OOo to view the file. This method lacks 
 		error handling (TODO)."""
 		items = event.widget.curselection()
-		filename = "%s%s" % (self.search_path.get(), event.widget.get(items[0]))
+		filename = os.path.join(self.search_path.get(), event.widget.get(items[0]))
 		filename = os.path.normpath(filename)
 		prg = self.ooo_path.get()
 		if not prg:
@@ -223,10 +223,7 @@ class Application(object):
 			cmd = "\"%s\" \"%s\" &" % (prg, filename)
 			self.status.config(text=_("Starting viewer..."))
 			print(cmd)
-			try:
-				res = os.system(cmd)
-			except UnicodeError:
-				res = os.system(cmd)
+			res = os.system(cmd)
 			if res != 0:
 				# don't show a dialog, this check might not be system-indepenent:
 				print(_("Warning: Command returned code != 0: ") + cmd)
@@ -273,6 +270,8 @@ class Application(object):
 
 	def processFile(self, filename, query):
 		suffix = self.getSuffix(filename)
+		# needed for error messages
+		fsfilename =filename
 		try:
 			# Handle OpenOffice.org files:
 			if suffix in ('sxw', 'stw',		# OOo   1.x swriter
@@ -299,7 +298,7 @@ class Application(object):
 
 						if filename.endswith("document.xml"):
 							content += str(zip.read(filename), 'utf-8')
-							
+
 					content = self.removeXMLMarkup(content, replace_with_space=0)
 					docinfo = str(zip.read("meta.xml"), 'utf-8')
 					docinfo = self.removeXMLMarkup(docinfo, replace_with_space=0)
@@ -307,6 +306,10 @@ class Application(object):
 				except KeyError as err:
 					print("Warning: %s not found in '%s'" % (err, filename))
 					return None
+				# Patch for encrypted files
+				except UnicodeDecodeError:
+					print("Warning: cannot open '%s'" % (fsfilename))
+					return None
 				title = ""
 				title_match = re.compile("<dc:title>(.*?)</dc:title>", re.DOTALL|re.IGNORECASE).search(docinfo)
 				if title_match:
@@ -339,6 +342,10 @@ class Application(object):
 				except KeyError as err:
 					print("Warning: %s not found in '%s'" % (err, filename))
 					return None
+				# Patch for encrypted files
+				except UnicodeDecodeError:
+					print("Warning: cannot open '%s'" % (fsfilename))
+					return None
 				title = ""
 				title_match = re.compile("<dc:title>(.*?)</dc:title>", re.DOTALL|re.IGNORECASE).search(docinfo)
 				if title_match:
@@ -368,6 +375,10 @@ class Application(object):
 				except KeyError as err:
 					print("Warning: %s not found in '%s'" % (err, filename))
 					return None
+				# Patch for encrypted files
+				except UnicodeDecodeError:
+					print("Warning: cannot open '%s'" % (fsfilename))
+					return None
 				title = ""
 				title_match = re.compile("<dc:title>(.*?)</dc:title>", re.DOTALL|re.IGNORECASE).search(docinfo)
 				if title_match:
@@ -555,7 +566,7 @@ class TranslationIntegration(object):
 
 if __name__ == "__main__":
 
-	version = "0.8.4"
+	version = "0.8.5"
 	loookversion = "loook-" + version
 	
 	g = TranslationIntegration(loookversion) 
